@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import logging
 import os
 
 from red_commons.logging import RedTraceLogger
@@ -10,6 +11,8 @@ maybe_update_logger_class()
 
 LOGGER_PREFIX = os.getenv("PYLAV__LOGGER_PREFIX")
 
+logging.getLogger("deepdiff.diff").setLevel(logging.FATAL)
+
 if LOGGER_PREFIX is None:
     try:
         from redbot.core.utils import AsyncIter  # noqa:
