@@ -1,12 +1,15 @@
 from __future__ import annotations
 
+import asyncio
 import contextlib
+import gzip
 import pathlib
 import re
 from collections.abc import AsyncIterator
 from typing import TYPE_CHECKING, Literal
 
 import aiohttp
+import yaml
 from discord.utils import maybe_coroutine
 
 from pylav._logging import getLogger
@@ -205,6 +208,7 @@ class Query:
         index=0,
         query_type: Literal["single", "playlist", "album"] = None,
         recursive: bool = False,
+        special_local: bool = False,
     ):
         self._query = query
         self._source = source
@@ -213,6 +217,7 @@ class Query:
         self.index = index
         self._type = query_type or "single"
         self._recursive = recursive
+        self._special_local = special_local
         from pylav.localfiles import LocalFile
 
         self.__localfile_cls = LocalFile
@@ -225,7 +230,7 @@ class Query:
         start_time: bool = False,
         index: bool = False,
         recursive: bool = False,
-    ) -> Query:
+    ):
         if source:
             self._source = query.source
         if search:
@@ -306,7 +311,7 @@ class Query:
 
     @property
     def is_local(self) -> bool:
-        return self.source == "Local Files"
+        return self.source == "Local Files" or (self._special_local and (self.is_m3u or self.is_pls or self.is_pylav))
 
     @property
     def is_niconico(self) -> bool:
@@ -448,6 +453,21 @@ class Query:
             else:
                 return cls(query, "YouTube Music", search=True)  # Fallback to YouTube
 
+    @classmethod
+    async def __process_local_playlist(cls, query: str) -> LocalFile:
+        path: aiopath.AsyncPath = aiopath.AsyncPath(query)
+        if not await path.exists():
+            path_paths = path.parts[1:] if await maybe_coroutine(path.is_absolute) else path.parts
+            path = cls.__localfile_cls._ROOT_FOLDER.joinpath(*path_paths)
+            if not await path.exists():
+                raise ValueError(f"{path} does not exist")
+        try:
+            local_path = cls.__localfile_cls(await maybe_coroutine(path.absolute))
+            await local_path.initialize()
+        except Exception as e:
+            raise ValueError(f"{e}") from e
+        return local_path
+
     @classmethod
     async def __process_local(cls, query: str | pathlib.Path | aiopath.AsyncPath) -> Query:
         if cls.__localfile_cls is None:
@@ -456,8 +476,8 @@ class Query:
             cls.__localfile_cls = LocalFile
         recursively = False
         query = f"{query}"
-        if match := M3U_REGEX.match(query):
-            return cls(query, "M3U", query_type="album")
+        if playlist_cls := await cls.__process_playlist(query):
+            return playlist_cls
         if match := LOCAL_TRACK_URI_REGEX.match(query):
             query = match.group("local_file").strip()
         elif match := LOCAL_TRACK_NESTED.match(query):
@@ -479,14 +499,14 @@ class Query:
 
     @classmethod
     async def __process_playlist(cls, query: str) -> Query | None:
+        url = is_url(query)
+        query_final = query if url else await cls.__process_local_playlist(query)
         if __ := M3U_REGEX.match(query):
-            return cls(query, "M3U", query_type="album")
+            return cls(query_final, "M3U", query_type="album", special_local=not url)
         elif __ := PLS_REGEX.match(query):
-            return cls(query, "PLS", query_type="album")
-        # elif __ := XSPF_REGEX.match(query):
-        #     return cls(query, "XSPF", query_type="album")
+            return cls(query_final, "PLS", query_type="album", special_local=not url)
         elif __ := PYLAV_REGEX.match(query):
-            return cls(query, "PyLav", query_type="album")
+            return cls(query_final, "PyLav", query_type="album", special_local=not url)
 
     @classmethod
     async def from_string(
@@ -494,7 +514,7 @@ class Query:
     ) -> Query:
         if isinstance(query, Query):
             return query
-        if isinstance(query, pathlib.Path):
+        if isinstance(query, (aiopath.AsyncPath, pathlib.Path)):
             try:
                 return await cls.__process_local(query)
             except Exception:
@@ -506,30 +526,40 @@ class Query:
         source = None
         if len(query) > 20 and BASE64_TEST_REGEX.match(query):
             with contextlib.suppress(Exception):
-                data, _ = decode_track(query)
+                data, _ = await asyncio.to_thread(decode_track, query)
                 source = data["info"]["source"]
                 query = data["info"]["uri"]
-        if not dont_search and (output := await cls.__process_playlist(query)):
-            if source:
-                output._source = cls.__get_source_from_str(source)
-            return output
-        if (output := cls.__process_urls(query)) or (output := cls.__process_search(query)):
-            if source:
-                output._source = cls.__get_source_from_str(source)
-            return output
-        else:
-            try:
-                output = await cls.__process_local(query)
+        try:
+            if not dont_search and (output := await cls.__process_playlist(query)):
                 if source:
                     output._source = cls.__get_source_from_str(source)
                 return output
-            except Exception:
-                if dont_search:
-                    return cls("invalid", "invalid")
-                output = cls(query, "YouTube Music", search=True)
+            if (output := cls.__process_urls(query)) or (output := cls.__process_search(query)):
                 if source:
                     output._source = cls.__get_source_from_str(source)
-                return output  # Fallback to YouTube Music
+                return output
+            else:
+                try:
+                    if is_url(query):
+                        raise ValueError
+                    output = await cls.__process_local(query)
+                    if source:
+                        output._source = cls.__get_source_from_str(source)
+                    return output
+                except Exception:
+                    if dont_search:
+                        return cls("invalid", "invalid")
+                    output = cls(query, "YouTube Music", search=True)
+                    if source:
+                        output._source = cls.__get_source_from_str(source)
+                    return output  # Fallback to YouTube Music
+        except Exception:
+            if dont_search:
+                return cls("invalid", "invalid")
+            output = cls(query, "YouTube Music", search=True)
+            if source:
+                output._source = cls.__get_source_from_str(source)
+            return output  # Fallback to YouTube Music
 
     @classmethod
     def from_string_noawait(cls, query: Query | str) -> Query:
@@ -575,31 +605,41 @@ class Query:
 
         if self.is_local:
             return await self._query.to_string_user(
-                max_length, name_only=name_only, ellipsis=ellipsis, with_emoji=with_emoji, no_extension=no_extension
+                max_length,
+                name_only=name_only,
+                ellipsis=ellipsis,
+                with_emoji=with_emoji,
+                no_extension=no_extension,
+                is_album=self.is_album,
             )
-
         if max_length and len(self._query) > max_length:
             if ellipsis:
                 return f"{self._query[: max_length - 1].strip()}" + "\N{HORIZONTAL ELLIPSIS}"
             else:
                 return self._query[:max_length].strip()
-
         return self._query
 
     async def _yield_pylav_file_tracks(self) -> AsyncIterator[Query]:
-        if self.is_pylav and self.is_album:
+        if not self.is_pylav or not self.is_album:
+            return
+        if self._special_local:
+            file = self._query.path
+        else:
             file = aiopath.AsyncPath(self._query)
-            if await file.exists():
-                async with file.open("r") as f:
-                    contents = await f.read()
+        if await file.exists():
+            async with file.open("rb") as f:
+                contents = await f.read()
+                with contextlib.suppress(gzip.BadGzipFile):
+                    contents = gzip.decompress(contents)
+                contents = yaml.safe_load(contents)
+                for track in contents.get("tracks", []):
+                    yield await Query.from_base64(track)
+        elif is_url(self._query):
+            async with aiohttp.ClientSession() as session:
+                async with session.get(self._query) as resp:
+                    contents = await resp.text()
                     for line in contents.splitlines():
                         yield await Query.from_string(line.strip(), dont_search=True)
-            elif is_url(self._query):
-                async with aiohttp.ClientSession() as session:
-                    async with session.get(self._query) as resp:
-                        contents = await resp.text()
-                        for line in contents.splitlines():
-                            yield await Query.from_string(line.strip(), dont_search=True)
 
     async def _yield_local_tracks(self) -> AsyncIterator[Query]:
         if self.is_album:
@@ -614,7 +654,7 @@ class Query:
 
     async def _yield_m3u_tracks(self) -> AsyncIterator[Query]:
         if self.is_m3u and self.is_album:
-            m3u8 = await load_m3u8(None, uri=self._query)
+            m3u8 = await load_m3u8(None, uri=f"{self._query}")
             for track in m3u8.files:
                 yield await Query.from_string(track, dont_search=True)
             for playlist in m3u8.playlists:
@@ -623,7 +663,10 @@ class Query:
     async def _yield_pls_tracks(self) -> AsyncIterator[Query]:
         if not self.is_pls or not self.is_album:
             return
-        file = aiopath.AsyncPath(self._query)
+        if self._special_local:
+            file = self._query.path
+        else:
+            file = aiopath.AsyncPath(self._query)
         if await file.exists():
             async with file.open("r") as f:
                 contents = await f.read()
@@ -734,7 +777,7 @@ class Query:
 
     @classmethod
     async def from_base64(cls, base64_string: str) -> Query:
-        data, _ = decode_track(base64_string)
+        data, _ = await asyncio.to_thread(decode_track, base64_string)
         source = data["info"]["source"]
         url = data["info"]["uri"]
         response = await cls.from_string(url)
