@@ -85,8 +85,8 @@ except ImportError:
 from discord.ext.commands import Context as DpyContext  # isort:skip
 
 if TYPE_CHECKING:
-    from pylav import Player
     from pylav.node import Node
+    from pylav.player import Player
 
 __all__ = (
     "MISSING",
@@ -1033,7 +1033,7 @@ class PyLavContext(_OriginalContextClass):
             n_remaining = len(messages) - idx
             if n_remaining > 0:
                 query = await self.send(
-                    _("{} remaining. " "Type `more` to continue.").format(
+                    _("{} remaining. Type `more` to continue.").format(
                         _("There is still 1 message")
                         if n_remaining == 1
                         else _("There are still {remaning} messages").format(remaning=n_remaining)
